
# Slot: has active ingredient


holds between a drug and a chemical substance in which the latter is a part of the former, and is a biologically active component

URI: [biolink:has_active_ingredient](https://w3id.org/biolink/vocab/has_active_ingredient)


## Domain and Range

[Drug](Drug.md) &#8594;  <sub>0..\*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has part](has_part.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002248 |
| **In Subsets:** | | translator_minimal |

